# StudentAssist
## The A+ Labs: CSC433 Project

To setup the initial webserver:
- Execute `git clone https://github.com/wesleyaou/CSC433.git`
- Change into the StudentAssist/ directory, `cd CSC433/StudentAssist/`
- Run the webserver using `python3 main.py`
- In your browser, navigate to <http://localhost:5000/home>
